@@ -111,9 +111,11 @@ symbol_contract_map: Dict[str, ContractData] = {}
 
 class HtsGateway(BaseGateway):
     """
-    vn.py用于对接顶点HTS期权柜台的交易接口。
+    VeighNa用于对接顶点HTS期权柜台的交易接口。
     """
 
+    default_name: str = "HTS"
+
     default_setting: Dict[str, Any] = {
         "账号": "",
         "密码": "",
@@ -128,7 +130,7 @@ class HtsGateway(BaseGateway):
 
     exchanges: List[Exchange] = list(EXCHANGE_VT2HTS.keys())
 
-    def __init__(self, event_engine: EventEngine, gateway_name: str = "HTS") -> None:
+    def __init__(self, event_engine: EventEngine, gateway_name: str) -> None:
         """构造函数"""
         super().__init__(event_engine, gateway_name)
 
@@ -441,7 +443,7 @@ class HtsTdApi(TdApi):
             self.gateway.write_log(f"股票期权交易服务器登录成功")
             self.login_status = True
 
-            self.query_option_contracts()
+            self.query_option_contracts("")
         else:
             self.gateway.write_error("股票期权交易服务器登录失败", error)
 
@@ -590,7 +592,8 @@ class HtsTdApi(TdApi):
 
     def onRspSOPQryContactInfo(self, data: dict, error: dict, last: bool) -> None:
         """合约查询回报"""
-        if not data:
+        if not data["securityOptionID"]:
+            self.gateway.write_log("期权交易合约信息获取成功")
             return
 
         contract: ContractData = ContractData(
@@ -617,7 +620,8 @@ class HtsTdApi(TdApi):
         self.gateway.on_contract(contract)
 
         if last:
-            self.gateway.write_log("期权交易合约信息获取成功")
+            index: str = data["exchangeID"] + data["securityOptionID"]
+            self.query_option_contracts(index)
 
     def onRspSOPQryCapitalAccountInfo(self, data: dict, error: dict) -> None:
         """资金查询回报"""
@@ -749,12 +753,13 @@ class HtsTdApi(TdApi):
         }
         self.reqSOPQryPosition(req)
 
-    def query_option_contracts(self) -> None:
+    def query_option_contracts(self, index: str) -> None:
         """"""
         self.reqid += 1
         req: dict = {
             "requestID": self.reqid,
-            "accountID": self.accountid
+            "accountID": self.accountid,
+            "rowIndex": index
         }
         self.reqSOPQryContactInfo(req)
 
